<h2>Backup database</h2>
<form method="post" action=".">
  {% csrf_token %}
  {{ database_backup_form.as_p }}
  <div class="submit-row">
  <input type="submit" class="button" name="savebackup" value="Download database backup">
  </div>
</form>
<br/><hr/>

<h2>Backup media</h2>
<form method="post" action=".">
  {% csrf_token %}
  {{ media_backup_form.as_p }}
  <div class="submit-row">
    <input type="submit" class="button" name="mediabackup" value="Download media backup">
  </div>
</form>